merge_seshat_entry

Function merge_seshat_entry 

pub fn merge_seshat_entry(
    value: &mut Value,
    client: ClientKind,
) -> Result<(), CliError>
Merge the seshat entry into a parsed JSON Value.

Creates the mcpServers / mcp key if it doesn’t exist. Returns an error if value is not a JSON object (guards against corrupt config files that contain arrays, nulls, or bare scalars at root level).