pub struct App {
pub conventions: Vec<ConventionItem>,
pub current_index: usize,
pub results: Vec<ReviewAction>,
pub quit: bool,
pub saving: bool,
pub review_complete: bool,
pub search_mode: bool,
pub search_query: String,
pub filter_locked: bool,
pub filtered_indices: Vec<usize>,
/* private fields */
}Fields
conventions: Vec<ConventionItem>current_index: usizeresults: Vec<ReviewAction>quit: boolsaving: boolreview_complete: boolsearch_mode: boolsearch_query: Stringfilter_locked: boolfiltered_indices: Vec<usize>Implementations
Sourceimpl App
impl App
pub fn new(conventions: Vec<ConventionItem>) -> Self
pub fn filtered_current_index(&self) -> usize
pub fn filtered_total(&self) -> usize
pub fn filtered_current(&self) -> Option<&ConventionItem>
pub fn filtered_next(&mut self)
pub fn filtered_previous(&mut self)
pub fn push_search_char(&mut self, ch: char)
pub fn pop_search_char(&mut self)
pub fn lock_filter(&mut self)
pub fn cancel_search(&mut self)
pub fn mark_acted_on(&mut self, index: usize)
pub fn is_acted_on(&self, index: usize) -> bool
pub fn all_acted_on(&self) -> bool
Sourcepub fn advance_to_next_unreviewed(&mut self)
pub fn advance_to_next_unreviewed(&mut self)
Advance to the next un-reviewed convention.
Searches forward from current position, then wraps to the start.
If all conventions have been reviewed, sets quit = true.
pub fn current(&self) -> Option<&ConventionItem>
pub fn example_total(&self) -> usize
pub fn next_example(&mut self)
pub fn previous_example(&mut self)
pub fn next(&mut self)
pub fn previous(&mut self)
pub fn total(&self) -> usize