get_git_branches

Function get_git_branches 

pub fn get_git_branches(path: &Path) -> Vec<String>
Discover local git branch names for the repository containing path.

Uses gix to walk all local branches under refs/heads/. Returns an empty vec if the path is not in a git repository or no branches exist.